//   ***************************************************************************************************
//   ***************************************************************************************************
//   ***************************************************************************************************
//   K1 Force Inferno (sa_inf_thr.nss).
//   Created by Star Admiral.
//   Last Modified on 01/14/09.
//   ***************************************************************************************************
//   ***************************************************************************************************
//   ***************************************************************************************************

// Include custom functions for spell casting.
#include "sa_inc_force"

void main() {

   // Set the amount and type of damage dealt.
   int nDamage = GetHitDice( OBJECT_SELF );
   if( nDamage > 10 )
      nDamage = 10;
   nDamage = d8( nDamage );
   int nType = DAMAGE_TYPE_FIRE;

   // Set the visuals shown by the spell.
   effect eVisual = EffectVisualEffect( 1039, FALSE );
   effect eBump = EffectVisualEffect( 2062, FALSE );
   effect eBeam = EffectBeam( 2053, OBJECT_SELF, BODY_NODE_HAND_LEFT, FALSE );

   // Declare effect variables.
   effect eHorror = EffectHorrified();
   effect eDamage;

   // Set the effect icon for the spell.
   eHorror = SetEffectIcon( eHorror, SA_INF_I_THR );

   // If the character is not a party member, remove any stealth effects on the character only.
   if( !IsObjectPartyMember( OBJECT_SELF ) ) {
      SA_RemoveEffectSingle( SA_STEALTH_ONE, OBJECT_SELF );
      SA_RemoveEffectSingle( SA_CAMOUFLAGE_TWO, OBJECT_SELF );
   }
   // If the character is a party member, remove the stealth effects for the whole party.
   else {
      SA_RemoveEffectParty( SA_STEALTH_ONE );
      SA_RemoveEffectParty( SA_CAMOUFLAGE_TWO );
   }

   // Get the targeted character.
   object oTarget = GetFirstObjectInShape( SHAPE_SPHERE, 15.00, GetLocation( OBJECT_SELF ), TRUE, OBJECT_TYPE_CREATURE );

   // Check if the target is valid.
   while( GetIsObjectValid( oTarget ) ) {
      // Check if the target is an enemy.
      if( GetIsEnemy( oTarget ) ) {
         // If the target does not resist the power, apply it.
         if( !ResistForce( OBJECT_SELF, oTarget ) ) {
            // Apply the visual effects to the target.
            SA_ApplySpecialSingle( oTarget, DURATION_TYPE_TEMPORARY, eBeam, 1.50 );
            SA_ApplySpecialSingle( oTarget, DURATION_TYPE_INSTANT, eVisual, 0.00 );
            DelayCommand( 0.25, SA_ApplySpecialSingle( oTarget, DURATION_TYPE_TEMPORARY, eBump, 1.50 ) );
            // If the target fails the Will save, apply full damage and horror effect.
            if( !WillSave( oTarget, SA_DCSave(), SAVING_THROW_TYPE_NONE, OBJECT_SELF ) ) {
               eDamage = EffectDamage( nDamage, nType, DAMAGE_POWER_NORMAL );
               SA_ApplyEffectSingle( SA_INFERNO_THR, oTarget, TRUE, DURATION_TYPE_INSTANT, eDamage, 0.00 );
               SA_ApplySpecialSingle( oTarget, DURATION_TYPE_TEMPORARY, eHorror, 6.00 );
            }
            // If the target makes the Will save, half the damage and negate the horror effect.
            else {
               eDamage = EffectDamage( nDamage / 2, nType, DAMAGE_POWER_NORMAL );
               SA_ApplyEffectSingle( SA_INFERNO_THR, oTarget, TRUE, DURATION_TYPE_INSTANT, eDamage, 0.00 );
            }
         }
         // If the target resists the power, do nothing.
         else
            SA_ApplySpecialSingle( oTarget, DURATION_TYPE_INSTANT, EffectForceFizzle(), 0.00 );
      }
      // Get the next target in the sphere of effect.
      oTarget = GetNextObjectInShape( SHAPE_SPHERE, 15.00, GetLocation( OBJECT_SELF ), TRUE, OBJECT_TYPE_CREATURE );
   }

}
