//   ***************************************************************************************************
//   ***************************************************************************************************
//   ***************************************************************************************************
//   K1 Master Pull (sa_pul_imp.nss).
//   Created by Star Admiral.
//   Last Modified on 01/14/09.
//   ***************************************************************************************************
//   ***************************************************************************************************
//   ***************************************************************************************************

// Include custom functions for spell casting.
#include "sa_inc_force"

void main() {

   // Set the amount and type of damage dealt.
   int nDamage = GetHitDice( OBJECT_SELF );
   int nType = DAMAGE_TYPE_BLUDGEONING;

   // Set the visuals shown by the spell.
   effect eVisual = EffectVisualEffect( 1014, FALSE );
   effect eJump = EffectForceJump( OBJECT_SELF, 2 );

   // Declare effect variables.
   effect eStun;
   effect eDamage;

   // If the character is not a party member, remove any stealth effects on the character only.
   if( !IsObjectPartyMember( OBJECT_SELF ) ) {
      SA_RemoveEffectSingle( SA_STEALTH_ONE, OBJECT_SELF );
      SA_RemoveEffectSingle( SA_CAMOUFLAGE_TWO, OBJECT_SELF );
   }
   // If the character is a party member, remove the stealth effects for the whole party.
   else {
      SA_RemoveEffectParty( SA_STEALTH_ONE );
      SA_RemoveEffectParty( SA_CAMOUFLAGE_TWO );
   }

   // Get the targeted character.
   object oTarget = GetFirstObjectInShape( SHAPE_SPHERE, 15.00, GetLocation( OBJECT_SELF ), TRUE, OBJECT_TYPE_CREATURE );

   // Check if the target is valid.
   while( GetIsObjectValid( oTarget ) ) {
      // Check if the target is an enemy.
      if( GetIsEnemy( oTarget ) ) {
         // If the target is a droid, use the droid stun effect.
         if( GetRacialType( oTarget ) == RACIAL_TYPE_DROID )
            eStun = EffectDroidStun();
         // Otherwise, use the normal stun effect.
         else
            eStun = EffectStunned();
         // Set the effect icon for the spell.
         eStun = SetEffectIcon( eStun, SA_PUL_I_MAS );
         // If the target does not resist the power, apply it.
         if( !ResistForce( OBJECT_SELF, oTarget ) ) {
            // Apply the visual effects to the target.
            SA_ApplySpecialSingle( oTarget, DURATION_TYPE_INSTANT, eVisual, 0.00 );
            SA_ApplySpecialSingle( oTarget, DURATION_TYPE_INSTANT, eJump, 0.00 );
            // If the target fails the Reflex save, apply full damage and stun effect.
            if( !ReflexSave( oTarget, SA_DCSave(), SAVING_THROW_TYPE_NONE, OBJECT_SELF ) ) {
               eDamage = EffectDamage( nDamage, nType, DAMAGE_POWER_NORMAL );
               SA_ApplyEffectSingle( SA_PULL_REG, oTarget, TRUE, DURATION_TYPE_INSTANT, eDamage, 0.00 );
               SA_ApplySpecialSingle( oTarget, DURATION_TYPE_TEMPORARY, eStun, 6.00 );
            }
            // If the target makes the Reflex save, half the damage and negate the stun effect.
            else {
               eDamage = EffectDamage( nDamage / 2, nType, DAMAGE_POWER_NORMAL );
               SA_ApplyEffectSingle( SA_PULL_REG, oTarget, TRUE, DURATION_TYPE_INSTANT, eDamage, 0.00 );
            }
         }
         // If the target resists the power, do nothing.
         else
            SA_ApplySpecialSingle( oTarget, DURATION_TYPE_INSTANT, EffectForceFizzle(), 0.00 );
      }
      // Get the next target in the cylinder of effect.
      oTarget = GetNextObjectInShape( SHAPE_SPHERE, 15.00, GetLocation( OBJECT_SELF ), TRUE, OBJECT_TYPE_CREATURE );
   }

}
