//   ***************************************************************************************************
//   ***************************************************************************************************
//   ***************************************************************************************************
//   K1 Force Stealth (sa_ste_one.nss).
//   Created by Star Admiral.
//   Last Modified on 01/14/09.
//   ***************************************************************************************************
//   ***************************************************************************************************
//   ***************************************************************************************************

// Include custom functions for spell casting.
#include "sa_inc_force"

void main() {

   // Check if the character is not in combat.
   if( !GetIsInCombat( OBJECT_SELF ) ) {
      // If the spell's higher levels have not yet been cast by the character, cast the spell, else, do nothing.
      if( !GetHasSpellEffect( SA_CAMOUFLAGE_TWO, OBJECT_SELF ) ) {
         // Set the effects for stealth mode.
         effect eStealth = EffectInvisibility( INVISIBILITY_TYPE_NORMAL );
         eStealth = EffectLinkEffects( eStealth, EffectVisualEffect( 8000, FALSE ) );
         // Set the effect icon for the spell.
         eStealth = SetEffectIcon( eStealth, SA_STE_I_ONE );
         // Set the visuals shown by the spell.
         effect eVisual = EffectVisualEffect( 8001, FALSE );
         // Check if the character is not a party member.
         if( !IsObjectPartyMember( OBJECT_SELF ) ) {
            // Remove the spell effects if it exists already.
            SA_RemoveEffectSingle( SA_STEALTH_ONE, OBJECT_SELF );
            // Apply the effects to the character.
            SA_ApplySpecialSingle( OBJECT_SELF, DURATION_TYPE_INSTANT, eVisual, 0.00 );
            DelayCommand( 0.25, SA_ApplyEffectSingle( SA_STEALTH_ONE, OBJECT_SELF, FALSE, DURATION_TYPE_TEMPORARY, eStealth, 30.00 ) );
            // Get the targeted character.
            object oTarget = GetFirstObjectInArea( OBJECT_INVALID, OBJECT_TYPE_CREATURE );
            // Loop through each target within the sphere of effect.
            while ( GetIsObjectValid( oTarget ) ) {
               // If target notices player but fails awareness check, clear action queue to forget player.
               if ( GetIsEnemy( oTarget ) && ( GetAttackTarget( oTarget ) == OBJECT_SELF ) && ( GetSkillRank( 3, oTarget ) <= ( GetSkillRank( 2, OBJECT_SELF ) + 4 ) ) )
                  AssignCommand( oTarget, ClearAllActions() );
               // Get the next target in the sphere of effect.
               oTarget = GetNextObjectInArea( OBJECT_INVALID, OBJECT_TYPE_CREATURE );
            }
         }
         // If the character is a party member, apply the effect to the entire party.
         else {
            // Remove the spell effect if it exists already.
            SA_RemoveEffectParty( SA_STEALTH_ONE );
            // Apply the effects to the entire party.
            SA_ApplySpecialParty( DURATION_TYPE_INSTANT, eVisual, 0.00 );
            DelayCommand( 0.25, SA_ApplyEffectParty( SA_STEALTH_ONE, FALSE, DURATION_TYPE_TEMPORARY, eStealth, 30.00 ) );
            // Get the targeted character.
            object oTarget = GetFirstObjectInArea( OBJECT_INVALID, OBJECT_TYPE_CREATURE );
            // Loop through each target within the sphere of effect.
            while ( GetIsObjectValid( oTarget ) ) {
               // If target notices player but fails awareness check, clear action queue to forget player.
               if( GetIsEnemy( oTarget ) && ( GetAttackTarget( oTarget ) == OBJECT_SELF ) && ( GetSkillRank( 3, oTarget ) <= ( GetSkillRank( 2, OBJECT_SELF ) + 4 ) ) )
                  AssignCommand( oTarget, ClearAllActions() );
               // Get the next target in the sphere of effect.
               oTarget = GetNextObjectInArea( OBJECT_INVALID, OBJECT_TYPE_CREATURE );
            }
         }
      }
   }
   // If character is in combat, fizzle out force power and display an explaination.
   else {
      ActionStartConversation( OBJECT_SELF, "sa_ste_com", FALSE, 0, FALSE, "", "", "", "", "", "", FALSE );
      ApplyEffectToObject( DURATION_TYPE_INSTANT, EffectForceFizzle(), OBJECT_SELF );
   }

}